summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--TAO/ChangeLog-99c7
-rw-r--r--TAO/orbsvcs/orbsvcs/IOR_Multicast.cpp9
2 files changed, 12 insertions, 4 deletions
diff --git a/TAO/ChangeLog-99c b/TAO/ChangeLog-99c
index 0b3a4672560..47b65ccb649 100644
--- a/TAO/ChangeLog-99c
+++ b/TAO/ChangeLog-99c
@@ -1,3 +1,10 @@
+Mon Apr 5 16:26:32 1999 Vishal Kachroo <vishal@merengue.cs.wustl.edu>
+
+ * orbsvcs/orbsvcs/IOR_Multicast.cpp (handle_input):
+ Fixed the handle_input () that handles the multicast to
+ work for both Naming and Trading Service. Thanks to
+ James CE Johnson <jcej@tragus.org> for reporting this.
+
Mon Apr 05 09:59:26 1999 David L. Levine <levine@cs.wustl.edu>
* tao/Makefile,docs/configurations.html: removed enabling of
diff --git a/TAO/orbsvcs/orbsvcs/IOR_Multicast.cpp b/TAO/orbsvcs/orbsvcs/IOR_Multicast.cpp
index a3013bf1f39..1c54e1c009d 100644
--- a/TAO/orbsvcs/orbsvcs/IOR_Multicast.cpp
+++ b/TAO/orbsvcs/orbsvcs/IOR_Multicast.cpp
@@ -134,13 +134,14 @@ TAO_IOR_Multicast::handle_input (ACE_HANDLE)
ACE_CString ior(this->ior_);
- if (ACE_OS::strcmp (service_name.in (), "NameService") != 0)
+ if ((ACE_OS::strcmp (service_name.in (), "NameService") != 0) &&
+ (ACE_OS::strcmp (service_name.in (), "TradingService") != 0))
{
// The client has requested an IOR other than for the Name
// Service. Lookup the table for the IOR. The call to find_ior
// will fill the ior for us if the service name is found in the
// table.
-
+
ACE_CString service (service_name.in ());
if (this->ior_lookup_table_.find_ior (service, ior) != 0)
@@ -148,7 +149,7 @@ TAO_IOR_Multicast::handle_input (ACE_HANDLE)
"IOR_Multicast::find failed.\n"),
0);
}
-
+
ACE_SOCK_Connector connector;
ACE_INET_Addr peer_addr (ACE_NTOHS (remote_port),
remote_addr.get_host_name ());
@@ -134,13 +134,14 @@ TAO_IOR_Multicast::handle_input (ACE_HANDLE)
{
- // The client has requested an IOR other than for the Name
+ // The client has requested an IOR other than for the Name/Trading
// Service. Lookup the table for the IOR. The call to find_ior
// will fill the ior for us if the service name is found in the